# Use rpmbuild --with checks to enable running the test suite (disabled by default)
%{!?_with_checks:   %{!?_without_checks: %global _without_checks --without-checks}}
%{?_with_checks:    %global enable_checks 1}
%{?_without_checks: %global enable_checks 0}

Name:		compat-libspf2
Version:	1.0.4
Release:	12
Summary:	An old implementation of the SPF specification
License:	BSD or LGPLv2+
Group:		System Environment/Libraries
URL:		http://www.libspf2.org/
Source:		http://www.libspf2.org/spf/libspf2-%{version}.tar.gz
Patch0:		libspf2-1.0.4-case-insensitive.patch
Patch1:		libspf2-resolv.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
%if %{enable_checks}
# rpmbuild < 4.1.1 does not support %%check; see below
BuildRequires:	rpm-build >= 4.1.1, perl
%endif
Provides:	spf
Provides:	libspf2 = %{version}-%{release}
Obsoletes:	libspf2 < %{version}-%{release}

%description
libspf2 is an implementation of the SPF (Sender Policy Framework)
specification as found at:
http://www.ietf.org/internet-drafts/draft-mengwong-spf-00.txt
SPF allows email systems to check SPF DNS records and make sure that
an email is authorized by the administrator of the domain name that
it is coming from. This prevents email forgery, commonly used by
spammers, scammers, and email viruses/worms.

A lot of effort has been put into making it secure by design, and a
great deal of effort has been put into the regression tests.

%package devel
Summary:	Development tools needed to build programs that use libspf2
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Provides:	libspf2-devel = %{version}-%{release}
Obsoletes:	libspf2-devel < %{version}-%{release}

%description devel
The compat-libspf2-devel package contains the header files and static
libraries necessary for developing programs using the libspf2 (Sender
Policy Framework) library version %{version}.

%package progs
Summary:	Programs for making SPF queries using compat-libspf2
Group:		Applications/Internet
Requires:	%{name} = %{version}-%{release}
Requires(post):	/usr/sbin/alternatives
Requires(preun): /usr/sbin/alternatives
Requires(postun): /usr/sbin/alternatives
Provides:	libspf2-progs = %{version}-%{release}
Obsoletes:	libspf2-progs < %{version}-%{release}

%description progs
Programs for making SPF queries and checking their results using
compat-libspf2.

%prep
%setup -q -n libspf2-%{version}

# Fix occasional case-sensitivity that shouldn't be there
%patch0 -p0

# Fix for res_query possibly being a macro
%patch1 -p1

# Don't go looking for autotools when we don't need them
touch aclocal.m4
touch Makefile.in
touch configure
touch config.h.in

%build
# The configure script checks for the existence of __ns_get16 and uses the
# system-supplied version if found, otherwise one from src/libreplace.
# However, this function is marked GLIBC_PRIVATE in recent versions of glibc
# and shouldn't be called even if the configure script finds it. So we make
# sure that the configure script always uses the version in src/libreplace.
# This prevents us getting an unresolvable dependency in the built RPM.
ac_cv_func___ns_get16=no
export ac_cv_func___ns_get16
./configure --prefix=%{_prefix} --libdir=%{_libdir} --bindir=%{_bindir} --includedir=%{_includedir}
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_bindir}/spf*_static
mv -f %{buildroot}%{_bindir}/spfquery		%{buildroot}%{_bindir}/spfquery.compat-libspf2
mv -f %{buildroot}%{_bindir}/spfd		%{buildroot}%{_bindir}/spfd.compat-libspf2

# Remove static libraries and libtool libraries
rm -f %{buildroot}%{_libdir}/*.a
rm -f %{buildroot}%{_libdir}/*.la

%if %{enable_checks}
# Delete the following line for legacy RPM versions (older than 4.1.1) if you wish to enable checks
%check
make check
%endif

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post progs
/usr/sbin/alternatives --install %{_bindir}/spfquery spf %{_bindir}/spfquery.compat-libspf2 20 \
	--slave %{_bindir}/spfd spf-daemon %{_bindir}/spfd.compat-libspf2
exit 0

%preun progs
if [ $1 = 0 ]; then
	/usr/sbin/alternatives --remove spf %{_bindir}/spfquery.compat-libspf2
fi
exit 0

%postun progs
if [ "$1" -ge "1" ]; then
	spf=`readlink /etc/alternatives/spf`
	if [ "$spf" == "%{_bindir}/spfquery.compat-libspf2" ]; then
		/usr/sbin/alternatives --set spf %{_bindir}/spfquery.compat-libspf2
	fi
fi
exit 0

%triggerpostun -- libspf2-progs <= 1.0.4-3
/usr/sbin/alternatives --auto spf

%files
%defattr(-,root,root,-)
%{_libdir}/libspf2.so.*
%doc README Changelog docs/*.txt INSTALL LICENSES TODO

%files devel
%defattr(-,root,root,-)
%{_includedir}/spf2/
%{_libdir}/libspf2.so
%doc docs/API

%files progs
%defattr(-,root,root,-)
%{_bindir}/spfd.compat-libspf2
%{_bindir}/spfquery.compat-libspf2
%{_bindir}/spftest
%{_bindir}/spf_example
%{_bindir}/spf_example_2mx

%changelog
* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> 1.0.4-12
- Make explicit compat-libspf2 package from old libspf2 1.0.4 branch
- Add subpackages so we can build against the compat library
- Provide/Obsolete libspf2 1.0.x
- Don't use macros for commands

* Mon Jun 22 2009 Paul Howarth <paul@city-fan.org> 1.0.4-11
- Remove redundant buildreqs glibc-devel and make
- Replace the huge autotools patch with a much smaller one made by using the
  same version of autoconf as upstream used to create the original
- Define RPM macros in global scope
- Remove Mandrake cruft
- Clarify license as BSD or LGPL version 2.1 or later
- Don't use deprecated "PreReq" tag
- Disable tests by default - don't seem to work any more (defunct DNS data?)
- Don't package static libraries and libtool libraries
- Own directory %%{_includedir}/spf2/

* Thu Feb 24 2005 Paul Howarth <paul@city-fan.org> 1.0.4-10
- Remove Provides: libspf2 in compat mode, which creates implicit conflicts
  with other libspf2 packages
- Further tweaks to detection of Mandrake build system
- Update patch for res_query detection

* Sun Feb 20 2005 Paul Howarth <paul@city-fan.org> 1.0.4-9
- Enhance detection of Mandrake build system
- Add support for building compat-libspf2 package
- alternatives is a prerequisite for the -progs subpackage only

* Thu Oct 28 2004 Paul Howarth <paul@city-fan.org> 1.0.4-8
- Downgrade alternatives priority to 20 so that other implementations
  of spfquery will be preferred; there is still a case-sensitivity bug
  in libspf2 and no sign of an imminent fix.

* Mon Aug 16 2004 Paul Howarth <paul@city-fan.org> 1.0.4-7
- Configure fix to find -lresolv on x64_64
- Portability fixes for x64_64

* Sun Aug  1 2004 Paul Howarth <paul@city-fan.org> 1.0.4-6
- Fix case-sensitivity bug.

* Wed Jul 28 2004 Paul Howarth <paul@city-fan.org> 1.0.4-5
- Revert -pthread option as it didn't improve anything.

* Tue Jul 27 2004 Paul Howarth <paul@city-fan.org> 1.0.4-4
- Use `alternatives' so that the spfquery and spfd programs can co-exist
  with versions from other implementations.
- Ensure thread-safe operation by building with -pthread.

* Thu Jul 15 2004 Paul Howarth <paul@city-fan.org> 1.0.4-3
- Install the libtool library in the devel package so that
  dependent libraries are found properly.
- Use the libtool supplied with the package rather than the
  system libtool.

* Tue Jul 13 2004 Paul Howarth <paul@city-fan.org> 1.0.4-2
- Cosmetic changes for building on Mandrake Linux
- Require rpm-build >= 4.1.1 for building to avoid strange error messages
  from old versions of rpm when they see %%check
- Require glibc-devel and make for building
- Require perl for building with checks enabled
- Improved description text for the packages

* Fri Jul 09 2004 Paul Howarth <paul@city-fan.org> 1.0.4-1
- Update to 1.0.4
- Added facility to build without running test suite
  (rpmbuild --without checks)

* Sat Jul 03 2004 Paul Howarth <paul@city-fan.org> 1.0.3-1
- Initial RPM build.
